====================================
2020-08-31 Reinstate weekly meetings
====================================

In a previous resolution titled 2017-04-25 Replace Technical Committee meetings,
the TC considered that weekly meetings were a participation barrier for TC and
non-TC members. Furthermore, office hours were issued as a solution to provide
global sensitivity and be mindful of the challenges non-native English speakers
and teams spread across the globe. Office hours were meant to eliminate time
limitations, offer alternative time slots so people everywhere can join, and
afford more open communications.

When weekly meetings were replaced, it was noted that meeting every week allows
regular cadence to keep progress moving forward. Without the weekly meetings, it
was required to maintain this cadence.

Presently, office hours don’t entirely substitute weekly meetings. While office
hours provide several advantages, in reality, the benefits of running weekly
meetings have been lost without a proper replacement.

Current Challenges
------------------
There are significant challenges experienced with conducting office hours
instead of weekly meetings; the main ones being:

* Involvement is very little during office hours.
* The TC is not getting things done quickly; it takes too long to merge changes,
  and to meet once a month means following up on progress is very slow.
* Engagement is minimum; there is almost no conversations are happening now.

Additionally, without regular meetings, the TC lost essential aspects that can
be brought back with the weekly meetings, for instance:

* A quorum of the TC is required to hold the meeting.
* The meeting agenda is a reasonably concise summary of what the TC is doing.
* The IRC logs of the meeting read alongside Gerrit are a good record of the
  debate.
* The meeting can be a quick way to reach out to the TC members to discuss how
  to move a particular proposal or idea forward.
* The meeting is an instrument to make time to resolve disagreements and build
  consensus around the particular topics that need progress.
* The meeting provides a weekly rhythm that forces TC members to regularly pay
  attention to TC initiatives and keep their efforts progressing.
* It’s a known time when other parts of the community can show up and interact
  with the TC.

Given that office hours don’t fully incorporate all of the advantages of weekly
meetings, these hours, in theory, could be considered as a complement of the
weekly meetings and not as a replacement.

Resolution
----------
Reinstate weekly meetings will ensure a faster flow of information, as regular
meetings help us keep up to date with each other.

Meetings are required to drive changes and follow up on progress in a timely
fashion; additionally, by having weekly meetings: 

* It will encourage the OpenStack community members to participate in
  discussions actively. 
* It will make it easy to have more open conversations.
* It will motivate members to carve 1 hour off their time once a week to follow
  up on projects progress.
* It is in-line with all the other teams inside OpenStack, who all meet once a
  week.
* The TC would be listening to several community members, OSF executives and
  board members, who have expressed the importance and visibility into it.